@@ -1046,7 +1046,7 @@ sub _ShowEdit {
                 my $ControllerClass = '';
                 if ( !$GIControllers{ $ActionData{Controller} } ) {
                     $NoControllerFound = 1;
-                    $ControllerClass   = 'Error',
+                    $ControllerClass   = 'Error';
                 }
 
                 $Self->{LayoutObject}->Block(
