@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminProcessManagementPath.pm - process management path
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -314,7 +313,7 @@ sub _ShowEdit {
         Data        => \@TransitionList,
         Name        => "Transition",
         ID          => "Transition",
-        Title       => $Self->{LayoutObject}->{LanguageObject}->Get("Transition"),
+        Title       => $Self->{LayoutObject}->{LanguageObject}->Translate("Transition"),
         Translation => 1,
         Class       => 'W50pc',
     );
@@ -407,7 +406,7 @@ sub _PushSessionScreen {
 
     # add screen to the screen path
     push @{ $Self->{ScreensPath} }, {
-        Action => $Self->{Action} || '',
+        Action          => $Self->{Action} || '',
         Subaction       => $Param{Subaction},
         ID              => $Param{ID},
         EntityID        => $Param{EntityID},
