@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -31,10 +31,11 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    my $SessionMaxIdleTime = $Self->{ConfigObject}->Get('SessionMaxIdleTime');
+
     # get session info
-    my %Online      = ();
-    my @Sessions    = $Self->{SessionObject}->GetAllSessionIDs();
-    my $IdleMinutes = $Param{Config}->{IdleMinutes} || 60 * 2;
+    my %Online   = ();
+    my @Sessions = $Self->{SessionObject}->GetAllSessionIDs();
     for (@Sessions) {
         my %Data = $Self->{SessionObject}->GetSessionIDData(
             SessionID => $_,
@@ -43,7 +44,7 @@ sub Run {
             $Self->{UserID} ne $Data{UserID}
             && $Data{UserType} eq 'User'
             && $Data{UserLastRequest}
-            && $Data{UserLastRequest} + ( $IdleMinutes * 60 ) > $Self->{TimeObject}->SystemTime()
+            && $Data{UserLastRequest} + $SessionMaxIdleTime > $Self->{TimeObject}->SystemTime()
             && $Data{UserFirstname}
             && $Data{UserLastname}
             )
