@@ -711,7 +711,7 @@ sub _Show {
             Space => ' ',
         );
         if ( 60 * 60 * 1 > $Article{FirstResponseTime} ) {
-            $Article{FirstResponseTimeClass} = 'Warning'
+            $Article{FirstResponseTimeClass} = 'Warning';
         }
         $Self->{LayoutObject}->Block(
             Name => 'FirstResponseTime',
@@ -730,7 +730,7 @@ sub _Show {
             Space => ' ',
         );
         if ( 60 * 60 * 1 > $Article{UpdateTime} ) {
-            $Article{UpdateTimeClass} = 'Warning'
+            $Article{UpdateTimeClass} = 'Warning';
         }
         $Self->{LayoutObject}->Block(
             Name => 'UpdateTime',
@@ -749,7 +749,7 @@ sub _Show {
             Space => ' ',
         );
         if ( 60 * 60 * 1 > $Article{SolutionTime} ) {
-            $Article{SolutionTimeClass} = 'Warning'
+            $Article{SolutionTimeClass} = 'Warning';
         }
         $Self->{LayoutObject}->Block(
             Name => 'SolutionTime',
