@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -214,8 +214,8 @@ sub EditFieldRender {
     );
 
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
-        Data => $DataValues || {},
-        Name => $FieldName,
+        Data        => $DataValues || {},
+        Name        => $FieldName,
         SelectedID  => $Value,
         Translation => $FieldConfig->{TranslatableValues} || 0,
         Class       => $FieldClass,
@@ -367,7 +367,7 @@ sub EditFieldValueValidate {
 
         # overwrite possible values if PossibleValuesFilter
         if ( defined $Param{PossibleValuesFilter} ) {
-            $PossibleValues = $Param{PossibleValuesFilter}
+            $PossibleValues = $Param{PossibleValuesFilter};
         }
 
         # validate if value is in possible values list (but let pass empty values)
@@ -495,7 +495,7 @@ sub SearchFieldRender {
     if ( IsHashRefWithData($HistoricalValues) ) {
         for my $Key ( sort keys %{$HistoricalValues} ) {
             if ( !$SelectionData->{$Key} ) {
-                $SelectionData->{$Key} = $HistoricalValues->{$Key}
+                $SelectionData->{$Key} = $HistoricalValues->{$Key};
             }
         }
     }
@@ -664,7 +664,7 @@ sub StatsFieldParameterBuild {
     # add historic values to current values (if they don't exist anymore)
     for my $Key ( sort keys %{$HistoricalValues} ) {
         if ( !$Values->{$Key} ) {
-            $Values->{$Key} = $HistoricalValues->{$Key}
+            $Values->{$Key} = $HistoricalValues->{$Key};
         }
     }
 
@@ -728,18 +728,18 @@ sub TemplateValueTypeGet {
     if ( $Param{FieldType} eq 'Edit' ) {
         return {
             $FieldName => $EditValueType,
-            }
+        };
     }
     elsif ( $Param{FieldType} eq 'Search' ) {
         return {
             'Search_' . $FieldName => $SearchValueType,
-            }
+        };
     }
     else {
         return {
             $FieldName             => $EditValueType,
             'Search_' . $FieldName => $SearchValueType,
-            }
+        };
     }
 }
 
@@ -978,7 +978,7 @@ sub ColumnFilterValuesGet {
     # get the display value if still exist in dynamic field configuration
     for my $Key ( sort keys %{$ColumnFilterValues} ) {
         if ( $SelectionData->{$Key} ) {
-            $ColumnFilterValues->{$Key} = $SelectionData->{$Key}
+            $ColumnFilterValues->{$Key} = $SelectionData->{$Key};
         }
     }
 
