@@ -1,6 +1,5 @@
 # --
-# Kernel/System/GenericAgent/NotifyAgentGroupOfCustomQueue.pm - generic agent notifications
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,9 +11,14 @@ package Kernel::System::GenericAgent::NotifyAgentGroupOfCustomQueue;
 use strict;
 use warnings;
 
-use Kernel::System::User;
-use Kernel::System::Email;
-use Kernel::System::Queue;
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Queue',
+    'Kernel::System::SLA',
+    'Kernel::System::Ticket',
+    'Kernel::System::Time',
+    'Kernel::System::User',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -23,41 +27,44 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(DBObject ConfigObject LogObject MainObject EncodeObject TicketObject TimeObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     # 0=off; 1=on;
     $Self->{Debug} = $Param{Debug} || 0;
 
-    $Self->{UserObject}  = Kernel::System::User->new( %{$Self} );
-    $Self->{EmailObject} = Kernel::System::Email->new( %{$Self} );
-    $Self->{QueueObject} = Kernel::System::Queue->new( %{$Self} );
-
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     # get ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet(
+    my %Ticket = $TicketObject->TicketGet(
         %Param,
         DynamicFields => 0,
     );
 
-    # check if bussines hours is, then send escalation info
-    my $CountedTime = $Self->{TimeObject}->WorkingTime(
-        StartTime => $Self->{TimeObject}->SystemTime() - ( 10 * 60 ),
-        StopTime => $Self->{TimeObject}->SystemTime(),
+    # get used calendar
+    my $Calendar = $TicketObject->TicketCalendarGet(
+        %Ticket,
+    );
+
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+
+    # check if it is during business hours, then send escalation info
+    my $CountedTime = $TimeObject->WorkingTime(
+        StartTime => $TimeObject->SystemTime() - ( 10 * 60 ),
+        StopTime  => $TimeObject->SystemTime(),
+        Calendar  => $Calendar,
     );
     if ( !$CountedTime ) {
         if ( $Self->{Debug} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message =>
-                    "Send not escalation for Ticket $Ticket{TicketNumber}/$Ticket{TicketID} because currently no working hours!",
+                    "Send no escalation for Ticket $Ticket{TicketNumber}/$Ticket{TicketID} because currently no working hours!",
             );
         }
         return 1;
@@ -66,6 +73,7 @@ sub Run {
     # check if it's a escalation of escalation notification
     # check escalation times
     my $EscalationType = '';
+    TYPE:
     for my $Type (
         qw(FirstResponseTimeEscalation UpdateTimeEscalation SolutionTimeEscalation
         FirstResponseTimeNotification UpdateTimeNotification SolutionTimeNotification)
@@ -74,11 +82,11 @@ sub Run {
         if ( defined $Ticket{$Type} ) {
             if ( $Type =~ /TimeEscalation$/ ) {
                 $EscalationType = 'Escalation';
-                last;
+                last TYPE;
             }
             elsif ( $Type =~ /TimeNotification$/ ) {
                 $EscalationType = 'EscalationNotifyBefore';
-                last;
+                last TYPE;
             }
         }
     }
@@ -86,7 +94,7 @@ sub Run {
     # check
     if ( !$EscalationType ) {
         if ( $Self->{Debug} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message =>
                     "Can't send escalation for Ticket $Ticket{TicketNumber}/$Ticket{TicketID} because ticket is not escalated!",
@@ -96,28 +104,36 @@ sub Run {
     }
 
     # get agentss who are sucscribed the ticket queue to the custom queues
-    my @UserIDs = $Self->{TicketObject}->GetSubscribedUserIDsByQueueID(
+    my @UserIDs = $TicketObject->GetSubscribedUserIDsByQueueID(
         QueueID => $Ticket{QueueID},
     );
 
+    # get user object
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
+
     # send each agent the escalation notification
+    USER:
     for my $UserID (@UserIDs) {
-        my %User = $Self->{UserObject}->GetUserData(
+
+        my %User = $UserObject->GetUserData(
             UserID => $UserID,
-            Valid  => 1
+            Valid  => 1,
         );
-        next if !%User || $User{OutOfOfficeMessage};
+
+        next USER if !%User || $User{OutOfOfficeMessage};
 
         # check if today a reminder is already sent
-        my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
-            SystemTime => $Self->{TimeObject}->SystemTime(),
+        my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $TimeObject->SystemTime2Date(
+            SystemTime => $TimeObject->SystemTime(),
         );
-        my @Lines = $Self->{TicketObject}->HistoryGet(
+        my @Lines = $TicketObject->HistoryGet(
             TicketID => $Ticket{TicketID},
             UserID   => 1,
         );
+
         my $Sent = 0;
         for my $Line (@Lines) {
+
             if (
                 $Line->{Name} =~ /\%\%$EscalationType\%\%/
                 && $Line->{Name} =~ /\Q%%$User{UserEmail}\E$/i
@@ -127,10 +143,11 @@ sub Run {
                 $Sent = 1;
             }
         }
-        next if $Sent;
+
+        next USER if $Sent;
 
         # send agent notification
-        $Self->{TicketObject}->SendAgentNotification(
+        $TicketObject->SendAgentNotification(
             TicketID              => $Param{TicketID},
             CustomerMessageParams => \%Param,
             Type                  => $EscalationType,
@@ -138,6 +155,7 @@ sub Run {
             UserID                => 1,
         );
     }
+
     return 1;
 }
 
