@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -552,12 +552,12 @@ sub HandleBusinessPermissionCloudServiceResult {
     #   cloud.otrs.com cannot be made temporarily.
     my %StoreData = (
         BusinessPermission => $OperationResult->{Data}->{BusinessPermission} // 0,
-        ExpiryDate         => $OperationResult->{Data}->{ExpiryDate}         // '',
+        ExpiryDate         => $OperationResult->{Data}->{ExpiryDate} // '',
         LastUpdateTime     => $Kernel::OM->Get('Kernel::System::Time')->SystemTime2TimeStamp(
             SystemTime => $Kernel::OM->Get('Kernel::System::Time')->SystemTime()
         ),
-        AgentSessionLimit             => $OperationResult->{Data}->{AgentSessionLimit},
-        AgentSessionLimitPriorWarning => $OperationResult->{Data}->{AgentSessionLimitPriorWarning},
+        AgentSessionLimit             => $OperationResult->{Data}->{AgentSessionLimit} // 0,
+        AgentSessionLimitPriorWarning => $OperationResult->{Data}->{AgentSessionLimitPriorWarning} // 0,
     );
 
     my $SystemDataObject = $Kernel::OM->Get('Kernel::System::SystemData');
@@ -596,7 +596,7 @@ sub HandleBusinessVersionCheckCloudServiceResult {
 
     my %StoreData = (
         LatestVersionForCurrentFramework => $OperationResult->{Data}->{LatestVersionForCurrentFramework} // '',
-        FrameworkUpdateAvailable         => $OperationResult->{Data}->{FrameworkUpdateAvailable}         // '',
+        FrameworkUpdateAvailable         => $OperationResult->{Data}->{FrameworkUpdateAvailable} // '',
     );
 
     my $SystemDataObject = $Kernel::OM->Get('Kernel::System::SystemData');
