@@ -1,6 +1,5 @@
 # --
-# Kernel/System/SupportDataCollector/Plugin/Webserver/Version.pm - system data collector plugin
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -25,6 +24,9 @@ sub Run {
 
     my %Environment = %ENV;
 
+    # Skip the plugin, if the support data collection isn't running in a web request.
+    return $Self->GetResults() if !$ENV{GATEWAY_INTERFACE};
+
     my $Version = $ENV{SERVER_SOFTWARE};
 
     if ($Version) {
