@@ -1,6 +1,5 @@
 # --
-# Kernel/System/Time.pm - time functions
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -374,9 +373,8 @@ sub MailTimeStamp {
 
     # According to RFC 2822, section 3.3
 
-    # ---
     # The date and time-of-day SHOULD express local time.
-
+    #
     # The zone specifies the offset from Coordinated Universal Time (UTC,
     # formerly referred to as "Greenwich Mean Time") that the date and
     # time-of-day represent.  The "+" or "-" indicates whether the
@@ -391,7 +389,6 @@ sub MailTimeStamp {
     # in a local time zone other than Universal Time and therefore
     # indicates that the date-time contains no information about the local
     # time zone.
-    # ---
 
     my @DayMap   = qw/Sun Mon Tue Wed Thu Fri Sat/;
     my @MonthMap = qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
@@ -664,6 +661,7 @@ sub DestinationTime {
     );
 
     my $LoopCounter;
+    my $DayLightSaving;
 
     LOOP:
     while ( $Param{Time} > 1 ) {
@@ -675,6 +673,20 @@ sub DestinationTime {
         $Month += 1;
         my $CTime00 = $CTime - ( ( $Hour * 60 + $Minute ) * 60 + $Second );               # 00:00:00
 
+        # compensate for switching to/from daylight saving time
+        # in case daylight saving time from 00:00:00 turned backward 1 hour to 23:00:00
+        if ( $DayLightSaving && $Hour == 23 ) {
+            $CTime += 3600;
+            $CTime00 = $CTime;
+
+            # there is needed next day, but $Day++ would be wrong in case it was end of month
+            ( $Second, $Minute, $Hour, $Day, $Month, $Year, $WDay ) = localtime $CTime + 1;
+            $Year  += 1900;
+            $Month += 1;
+
+            $DestinationTime += 3600;
+        }
+
         # Skip vacation days, or days without working hours, do not count.
         if (
             $TimeVacationDays->{$Month}->{$Day}
@@ -700,8 +712,8 @@ sub DestinationTime {
 
                 # Check if we have a working hour
                 if ( grep { $H == $_ } @{ $TimeWorkingHours->{ $LDay{$WDay} } } ) {
-                    if ( $Param{Time} > 60 * 60 ) {
-                        my $RestOfHour = 3600 - ( $Minute * 60 + $Second );
+                    my $RestOfHour = 3600 - ( $Minute * 60 + $Second );
+                    if ( $Param{Time} > $RestOfHour ) {
                         $DestinationTime += $RestOfHour;
                         $Param{Time} -= $RestOfHour;
                     }
@@ -738,6 +750,7 @@ sub DestinationTime {
         if ( $NewCTime != $CTime00 + 24 * 60 * 60 ) {
             my $Diff = $NewCTime - $CTime00 - 24 * 60 * 60;
             $DestinationTime += $Diff;
+            $DayLightSaving = 1;
         }
 
         # Set next loop time to 00:00:00 of next day.
