@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -281,7 +281,7 @@ sub GetUserData {
                 = "$Preferences{OutOfOfficeEndYear}-$Preferences{OutOfOfficeEndMonth}-$Preferences{OutOfOfficeEndDay}";
             if ( $TimeStart < $Time && $TimeEnd > $Time ) {
                 $Preferences{OutOfOfficeMessage} = "*** out of office till $TillDate/$Till d ***";
-                $Data{UserLastname} .= ' ' . $Preferences{OutOfOfficeMessage};
+                $Data{UserFullname} .= ' ' . $Preferences{OutOfOfficeMessage};
             }
 
             # Reduce CacheTTL to one hour for users that are out of office to make sure the cache expires timely
@@ -549,13 +549,7 @@ sub UserUpdate {
         Value  => $Param{UserEmail}
     );
 
-    # delete cache
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => $Self->{CacheType},
-    );
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => 'Group',
-    );
+    $Self->_UserCacheClear( UserID => $Param{UserID} );
 
     return 1;
 }
@@ -1150,11 +1144,32 @@ sub SetPreferences {
         && defined $Param{Value}
         && $User{ $Param{Key} } eq $Param{Value};
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    $Self->_UserCacheClear( UserID => $Param{UserID} );
+
+    # get user preferences config
+    my $GeneratorModule = $Kernel::OM->Get('Kernel::Config')->Get('User::PreferencesModule')
+        || 'Kernel::System::User::Preferences::DB';
+
+    # get generator preferences module
+    my $PreferencesObject = $Kernel::OM->Get($GeneratorModule);
+
+    # set preferences
+    return $PreferencesObject->SetPreferences(%Param);
+}
+
+sub _UserCacheClear {
+    my ( $Self, %Param ) = @_;
+
+    if ( !$Param{UserID} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need UserID!"
+        );
+        return;
+    }
 
     # get configuration for the full name order
-    my $FirstnameLastNameOrder = $ConfigObject->Get('FirstnameLastnameOrder') || 0;
+    my $FirstnameLastNameOrder = $Kernel::OM->Get('Kernel::Config')->Get('FirstnameLastnameOrder') || 0;
 
     # create cachekey
     my $Login = $Self->UserLookup( UserID => $Param{UserID} );
@@ -1175,6 +1190,8 @@ sub SetPreferences {
         'UserList::Long::0::' . $FirstnameLastNameOrder . '::1',
         'UserList::Long::1::' . $FirstnameLastNameOrder . '::0',
         'UserList::Long::1::' . $FirstnameLastNameOrder . '::1',
+        'UserLookup::ID::' . $Login,
+        'UserLookup::Login::' . $Param{UserID},
     );
 
     # get cache object
@@ -1189,15 +1206,7 @@ sub SetPreferences {
         );
     }
 
-    # get user preferences config
-    my $GeneratorModule = $ConfigObject->Get('User::PreferencesModule')
-        || 'Kernel::System::User::Preferences::DB';
-
-    # get generator preferences module
-    my $PreferencesObject = $Kernel::OM->Get($GeneratorModule);
-
-    # set preferences
-    return $PreferencesObject->SetPreferences(%Param);
+    return 1;
 }
 
 =item GetPreferences()
