@@ -1,7 +1,35 @@
 # ----------------------------------------------------------
-#  driver: mysql, generated: 2012-07-05 09:12:50
+#  driver: mysql
 # ----------------------------------------------------------
 # ----------------------------------------------------------
+#  create table acl
+# ----------------------------------------------------------
+CREATE TABLE acl (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    name VARCHAR (200) NOT NULL,
+    comments VARCHAR (250) NULL,
+    description VARCHAR (250) NULL,
+    valid_id SMALLINT NOT NULL,
+    stop_after_match SMALLINT NULL,
+    config_match LONGBLOB NULL,
+    config_change LONGBLOB NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE INDEX acl_name (name)
+);
+# ----------------------------------------------------------
+#  create table acl_sync
+# ----------------------------------------------------------
+CREATE TABLE acl_sync (
+    acl_id VARCHAR (200) NOT NULL,
+    sync_state VARCHAR (30) NOT NULL,
+    create_time DATETIME NOT NULL,
+    change_time DATETIME NOT NULL
+);
+# ----------------------------------------------------------
 #  create table valid
 # ----------------------------------------------------------
 CREATE TABLE valid (
@@ -38,7 +66,7 @@ CREATE TABLE users (
 CREATE TABLE user_preferences (
     user_id INTEGER NOT NULL,
     preferences_key VARCHAR (150) NOT NULL,
-    preferences_value VARCHAR (250) NULL,
+    preferences_value LONGBLOB NULL,
     INDEX user_preferences_user_id (user_id)
 );
 # ----------------------------------------------------------
@@ -139,6 +167,15 @@ CREATE TABLE personal_queues (
     INDEX personal_queues_user_id (user_id)
 );
 # ----------------------------------------------------------
+#  create table personal_services
+# ----------------------------------------------------------
+CREATE TABLE personal_services (
+    user_id INTEGER NOT NULL,
+    service_id INTEGER NOT NULL,
+    INDEX personal_services_service_id (service_id),
+    INDEX personal_services_user_id (user_id)
+);
+# ----------------------------------------------------------
 #  create table salutation
 # ----------------------------------------------------------
 CREATE TABLE salutation (
@@ -191,6 +228,24 @@ CREATE TABLE system_address (
     PRIMARY KEY(id)
 );
 # ----------------------------------------------------------
+#  create table system_maintenance
+# ----------------------------------------------------------
+CREATE TABLE system_maintenance (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    start_date INTEGER NOT NULL,
+    stop_date INTEGER NOT NULL,
+    comments VARCHAR (250) NOT NULL,
+    login_message VARCHAR (250) NULL,
+    show_login_message SMALLINT NULL,
+    notify_message VARCHAR (250) NULL,
+    valid_id SMALLINT NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id)
+);
+# ----------------------------------------------------------
 #  create table follow_up_possible
 # ----------------------------------------------------------
 CREATE TABLE follow_up_possible (
@@ -326,19 +381,13 @@ CREATE TABLE ticket (
     title VARCHAR (255) NULL,
     queue_id INTEGER NOT NULL,
     ticket_lock_id SMALLINT NOT NULL,
-    ticket_answered SMALLINT NOT NULL,
     type_id SMALLINT NULL,
     service_id INTEGER NULL,
     sla_id INTEGER NULL,
     user_id INTEGER NOT NULL,
     responsible_user_id INTEGER NOT NULL,
-    group_id INTEGER NOT NULL,
     ticket_priority_id SMALLINT NOT NULL,
     ticket_state_id SMALLINT NOT NULL,
-    group_read SMALLINT NULL,
-    group_write SMALLINT NULL,
-    other_read SMALLINT NULL,
-    other_write SMALLINT NULL,
     customer_id VARCHAR (150) NULL,
     customer_user_id VARCHAR (250) NULL,
     timeout INTEGER NOT NULL,
@@ -347,7 +396,6 @@ CREATE TABLE ticket (
     escalation_update_time INTEGER NOT NULL,
     escalation_response_time INTEGER NOT NULL,
     escalation_solution_time INTEGER NOT NULL,
-    valid_id SMALLINT NOT NULL,
     archive_flag SMALLINT NOT NULL DEFAULT 0,
     create_time_unix BIGINT NOT NULL,
     create_time DATETIME NOT NULL,
@@ -356,7 +404,6 @@ CREATE TABLE ticket (
     change_by INTEGER NOT NULL,
     PRIMARY KEY(id),
     UNIQUE INDEX ticket_tn (tn),
-    INDEX ticket_answered (ticket_answered),
     INDEX ticket_archive_flag (archive_flag),
     INDEX ticket_create_time (create_time),
     INDEX ticket_create_time_unix (create_time_unix),
@@ -367,7 +414,7 @@ CREATE TABLE ticket (
     INDEX ticket_escalation_time (escalation_time),
     INDEX ticket_escalation_update_time (escalation_update_time),
     INDEX ticket_queue_id (queue_id),
-    INDEX ticket_queue_view (ticket_state_id, ticket_lock_id, group_id),
+    INDEX ticket_queue_view (ticket_state_id, ticket_lock_id),
     INDEX ticket_responsible_user_id (responsible_user_id),
     INDEX ticket_ticket_lock_id (ticket_lock_id),
     INDEX ticket_ticket_priority_id (ticket_priority_id),
@@ -406,7 +453,6 @@ CREATE TABLE ticket_history (
     owner_id INTEGER NOT NULL,
     priority_id SMALLINT NOT NULL,
     state_id SMALLINT NOT NULL,
-    valid_id SMALLINT NOT NULL,
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
     change_time DATETIME NOT NULL,
@@ -520,9 +566,7 @@ CREATE TABLE article_flag (
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
     INDEX article_flag_article_id (article_id),
-    INDEX article_flag_article_id_article_key (article_id, article_key),
-    INDEX article_flag_article_id_create_by (article_id, create_by),
-    INDEX article_flag_create_by (create_by)
+    INDEX article_flag_article_id_create_by (article_id, create_by)
 );
 # ----------------------------------------------------------
 #  create table article
@@ -538,6 +582,7 @@ CREATE TABLE article (
     a_cc TEXT NULL,
     a_subject TEXT NULL,
     a_message_id TEXT NULL,
+    a_message_id_md5 VARCHAR (32) NULL,
     a_in_reply_to TEXT NULL,
     a_references TEXT NULL,
     a_content_type VARCHAR (250) NULL,
@@ -552,7 +597,7 @@ CREATE TABLE article (
     PRIMARY KEY(id),
     INDEX article_article_sender_type_id (article_sender_type_id),
     INDEX article_article_type_id (article_type_id),
-    INDEX article_message_id (a_message_id(255)),
+    INDEX article_message_id_md5 (a_message_id_md5),
     INDEX article_ticket_id (ticket_id)
 );
 # ----------------------------------------------------------
@@ -567,13 +612,11 @@ CREATE TABLE article_search (
     a_to TEXT NULL,
     a_cc TEXT NULL,
     a_subject TEXT NULL,
-    a_message_id TEXT NULL,
     a_body MEDIUMTEXT NOT NULL,
     incoming_time INTEGER NOT NULL,
     PRIMARY KEY(id),
     INDEX article_search_article_sender_type_id (article_sender_type_id),
     INDEX article_search_article_type_id (article_type_id),
-    INDEX article_search_message_id (a_message_id(255)),
     INDEX article_search_ticket_id (ticket_id)
 );
 # ----------------------------------------------------------
@@ -601,6 +644,7 @@ CREATE TABLE article_attachment (
     content_type TEXT NULL,
     content_id VARCHAR (250) NULL,
     content_alternative VARCHAR (50) NULL,
+    disposition VARCHAR (15) NULL,
     content LONGBLOB NOT NULL,
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
@@ -625,13 +669,14 @@ CREATE TABLE time_accounting (
     INDEX time_accounting_ticket_id (ticket_id)
 );
 # ----------------------------------------------------------
-#  create table standard_response
+#  create table standard_template
 # ----------------------------------------------------------
-CREATE TABLE standard_response (
+CREATE TABLE standard_template (
     id INTEGER NOT NULL AUTO_INCREMENT,
     name VARCHAR (200) NOT NULL,
     text TEXT NULL,
     content_type VARCHAR (250) NULL,
+    template_type VARCHAR (100) NOT NULL DEFAULT 'Answer',
     comments VARCHAR (250) NULL,
     valid_id SMALLINT NOT NULL,
     create_time DATETIME NOT NULL,
@@ -639,14 +684,14 @@ CREATE TABLE standard_response (
     change_time DATETIME NOT NULL,
     change_by INTEGER NOT NULL,
     PRIMARY KEY(id),
-    UNIQUE INDEX standard_response_name (name)
+    UNIQUE INDEX standard_template_name (name)
 );
 # ----------------------------------------------------------
-#  create table queue_standard_response
+#  create table queue_standard_template
 # ----------------------------------------------------------
-CREATE TABLE queue_standard_response (
+CREATE TABLE queue_standard_template (
     queue_id INTEGER NOT NULL,
-    standard_response_id INTEGER NOT NULL,
+    standard_template_id INTEGER NOT NULL,
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
     change_time DATETIME NOT NULL,
@@ -671,12 +716,12 @@ CREATE TABLE standard_attachment (
     UNIQUE INDEX standard_attachment_name (name)
 );
 # ----------------------------------------------------------
-#  create table standard_response_attachment
+#  create table standard_template_attachment
 # ----------------------------------------------------------
-CREATE TABLE standard_response_attachment (
+CREATE TABLE standard_template_attachment (
     id INTEGER NOT NULL AUTO_INCREMENT,
     standard_attachment_id INTEGER NOT NULL,
-    standard_response_id INTEGER NOT NULL,
+    standard_template_id INTEGER NOT NULL,
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
     change_time DATETIME NOT NULL,
@@ -811,9 +856,14 @@ CREATE TABLE service_sla (
 #  create table sessions
 # ----------------------------------------------------------
 CREATE TABLE sessions (
-    session_id VARCHAR (150) NOT NULL,
-    session_value TEXT NOT NULL,
-    PRIMARY KEY(session_id)
+    id BIGINT NOT NULL AUTO_INCREMENT,
+    session_id VARCHAR (100) NOT NULL,
+    data_key VARCHAR (100) NOT NULL,
+    data_value TEXT NULL,
+    serialized SMALLINT NOT NULL,
+    PRIMARY KEY(id),
+    INDEX sessions_data_key (data_key),
+    INDEX sessions_session_id_data_key (session_id, data_key)
 );
 # ----------------------------------------------------------
 #  create table customer_user
@@ -901,6 +951,7 @@ CREATE TABLE postmaster_filter (
     f_type VARCHAR (20) NOT NULL,
     f_key VARCHAR (200) NOT NULL,
     f_value VARCHAR (200) NOT NULL,
+    f_not SMALLINT NULL,
     INDEX postmaster_filter_f_name (f_name)
 );
 # ----------------------------------------------------------
@@ -943,6 +994,7 @@ CREATE TABLE web_upload_cache (
     content_id VARCHAR (250) NULL,
     content_size VARCHAR (30) NULL,
     content_type VARCHAR (250) NULL,
+    disposition VARCHAR (15) NULL,
     content LONGBLOB NOT NULL,
     create_time_unix BIGINT NOT NULL
 );
@@ -1045,6 +1097,18 @@ CREATE TABLE link_relation (
     UNIQUE INDEX link_relation_view (source_object_id, source_key, target_object_id, target_key, type_id)
 );
 # ----------------------------------------------------------
+#  create table system_data
+# ----------------------------------------------------------
+CREATE TABLE system_data (
+    data_key VARCHAR (160) NOT NULL,
+    data_value LONGBLOB NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(data_key)
+);
+# ----------------------------------------------------------
 #  create table xml_storage
 # ----------------------------------------------------------
 CREATE TABLE xml_storage (
@@ -1066,7 +1130,7 @@ CREATE TABLE virtual_fs (
     create_time DATETIME NOT NULL,
     PRIMARY KEY(id),
     INDEX virtual_fs_backend (backend(60)),
-    INDEX virtual_fs_filename (filename(350))
+    INDEX virtual_fs_filename (filename(255))
 );
 # ----------------------------------------------------------
 #  create table virtual_fs_preferences
@@ -1087,7 +1151,7 @@ CREATE TABLE virtual_fs_db (
     content LONGBLOB NOT NULL,
     create_time DATETIME NOT NULL,
     PRIMARY KEY(id),
-    INDEX virtual_fs_db_filename (filename(350))
+    INDEX virtual_fs_db_filename (filename(255))
 );
 # ----------------------------------------------------------
 #  create table package_repository
@@ -1099,7 +1163,6 @@ CREATE TABLE package_repository (
     vendor VARCHAR (250) NOT NULL,
     install_status VARCHAR (250) NOT NULL,
     filename VARCHAR (250) NULL,
-    content_size VARCHAR (30) NULL,
     content_type VARCHAR (250) NULL,
     content LONGBLOB NOT NULL,
     create_time DATETIME NOT NULL,
@@ -1221,15 +1284,16 @@ CREATE TABLE dynamic_field_value (
     value_date DATETIME NULL,
     value_int BIGINT NULL,
     PRIMARY KEY(id),
-    INDEX index_field_values (field_id, object_id),
-    INDEX index_search_date (field_id, value_date),
-    INDEX index_search_int (field_id, value_int)
+    INDEX dynamic_field_value_field_values (object_id, field_id),
+    INDEX dynamic_field_value_search_date (field_id, value_date),
+    INDEX dynamic_field_value_search_int (field_id, value_int)
 );
 # ----------------------------------------------------------
 #  create table dynamic_field
 # ----------------------------------------------------------
 CREATE TABLE dynamic_field (
     id INTEGER NOT NULL AUTO_INCREMENT,
+    internal_field SMALLINT NOT NULL DEFAULT 0,
     name VARCHAR (200) NOT NULL,
     label VARCHAR (200) NOT NULL,
     field_order INTEGER NOT NULL,
@@ -1244,3 +1308,91 @@ CREATE TABLE dynamic_field (
     PRIMARY KEY(id),
     UNIQUE INDEX dynamic_field_name (name)
 );
+# ----------------------------------------------------------
+#  create table pm_process
+# ----------------------------------------------------------
+CREATE TABLE pm_process (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    entity_id VARCHAR (50) NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    state_entity_id VARCHAR (50) NOT NULL,
+    layout LONGBLOB NOT NULL,
+    config LONGBLOB NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE INDEX pm_process_entity_id (entity_id)
+);
+# ----------------------------------------------------------
+#  create table pm_activity
+# ----------------------------------------------------------
+CREATE TABLE pm_activity (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    entity_id VARCHAR (50) NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    config LONGBLOB NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE INDEX pm_activity_entity_id (entity_id)
+);
+# ----------------------------------------------------------
+#  create table pm_activity_dialog
+# ----------------------------------------------------------
+CREATE TABLE pm_activity_dialog (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    entity_id VARCHAR (50) NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    config LONGBLOB NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE INDEX pm_activity_dialog_entity_id (entity_id)
+);
+# ----------------------------------------------------------
+#  create table pm_transition
+# ----------------------------------------------------------
+CREATE TABLE pm_transition (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    entity_id VARCHAR (50) NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    config LONGBLOB NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE INDEX pm_transition_entity_id (entity_id)
+);
+# ----------------------------------------------------------
+#  create table pm_transition_action
+# ----------------------------------------------------------
+CREATE TABLE pm_transition_action (
+    id INTEGER NOT NULL AUTO_INCREMENT,
+    entity_id VARCHAR (50) NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    config LONGBLOB NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE INDEX pm_transition_action_entity_id (entity_id)
+);
+# ----------------------------------------------------------
+#  create table pm_entity_sync
+# ----------------------------------------------------------
+CREATE TABLE pm_entity_sync (
+    entity_type VARCHAR (30) NOT NULL,
+    entity_id VARCHAR (50) NOT NULL,
+    sync_state VARCHAR (30) NOT NULL,
+    create_time DATETIME NOT NULL,
+    change_time DATETIME NOT NULL,
+    UNIQUE INDEX pm_entity_sync_list (entity_type, entity_id)
+);
