@@ -1,8 +1,5 @@
 // --
-// Core.Config.UnitTest.js - UnitTests
-// Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
-// --
-// $Id: Core.Config.UnitTest.js,v 1.2 2010/08/17 12:14:12 mg Exp $
+// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/\n";
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -18,19 +15,23 @@ Core.Config = (function (Namespace) {
     Namespace.RunUnitTests = function(){
         module('Core.Config');
         test('Core.Config.Get()', function(){
-            expect(4);
+            expect(6);
 
             var ConfigTest = 'Test value';
             Core.Config.Set('Test', ConfigTest);
-            same(Core.Config.Get('Test'), ConfigTest);
+            deepEqual(Core.Config.Get('Test'), ConfigTest);
 
             Core.Config.Set('RichText.Test', ConfigTest);
-            same(Core.Config.Get('RichText.Test'), ConfigTest);
+            deepEqual(Core.Config.Get('RichText.Test'), ConfigTest);
 
             Core.Config.Set('RichText.Test2', ConfigTest);
-            same(Core.Config.Get('RichText.Test2'), ConfigTest);
+            deepEqual(Core.Config.Get('RichText.Test2'), ConfigTest);
 
-            same(Core.Config.Get('non.existing.dummy.ns'), undefined);
+            deepEqual(Core.Config.Get('non.existing.dummy.ns'), undefined);
+
+            deepEqual(Core.Config.Get('EasyName', 42), 42, "Test for default value");
+
+            deepEqual(Core.Config.Get('non.existing.dummy.ns', 'DefaultValueTest'), 'DefaultValueTest', "Test for default value 2");
         });
 
         test('Core.Config.AddConfig()', function(){
@@ -42,17 +43,17 @@ Core.Config = (function (Namespace) {
                 Name: 'Test'
             };
             Core.Config.AddConfig(ConfigTest, 'RichText');
-            same(Core.Config.Get('RichText'), ConfigTest);
+            deepEqual(Core.Config.Get('RichText'), ConfigTest);
 
             Core.Config.AddConfig(ConfigTest, 'RichText.Details');
-            same(Core.Config.Get('RichText.Details'), ConfigTest);
+            deepEqual(Core.Config.Get('RichText.Details'), ConfigTest);
 
             var ConfigTest = '{"Width":"600","Height":"400","Name":"Test"}';
 
             Core.Config.AddConfig(ConfigTest,'RichText.JSONStuff');
-            same(Core.Config.Get('RichText.JSONStuff'), ConfigTest);
+            deepEqual(Core.Config.Get('RichText.JSONStuff'), ConfigTest);
         });
     };
 
     return Namespace;
-}(Core.Config || {}));
\ No newline at end of file
+}(Core.Config || {}));
